Description: Pychemkin HTML Report.

# Pychemkin Report

# Reaction System

Temperature: 1500K

Reaction | Forward Reaction Coeff. (kf) | Backward Reaction Coeff. (kb)
--- | --- | ---
H + O2 ⇄ O + OH | 4.81192372122e+13 | 7.86833491894e+14
O + H2 ⇄ H + OH | 9.26791849643e+12 | 8.03264044779e+12
H2 + OH ⇄ H2O + H | 1.02542529949e+13 | 292668218111.0
O + H2O ⇄ 2OH | 2.64128027808e+12 | 8.02082563514e+13
HO2 + H ⇄ H2 + O2 | 1.55398795099e+13 | 394788.405885
HO2 + H ⇄ 2OH | 6.9135121237e+13 | 24891765.2564
HO2 + O ⇄ O2 + OH | 3.25e+13 | 715609.7113
HO2 + OH ⇄ H2O + O2 | 3.00749937131e+13 | 21806.8945313
H2O2 + H ⇄ H2O + OH | 1.75292917346e+13 | 243.077455449
H2O2 + H ⇄ HO2 + H2 | 2.54796493769e+13 | 34383117934.8
H2O2 + O ⇄ OH + HO2 | 1.56290728692e+13 | 18279366790.4

# Reaction system concentrations

Specie | Initial Concentration | Final Concentration
--- | --- | ---
H | 1.0 | 2.0370214813931593
O | 1.0 | 0.512042251358914
OH | 1.0 | 0.10164850964253505
H2 | 1.0 | 0.38160127265816035
H2O | 0.0 | 0.5490637308958995
O2 | 0.0 | 0.41862275219558126
HO2 | 0.0 | 1.8553086770899974e-09
H2O2 | 0.0 | 4.358067055356242e-13

System hasn't reached equilibrium yet

# Visualization

## Reaction Time Series

## Reaction Network

This diagram shows how species in the reaction system relate to one another. The size of the annulus around the species name scales linearly with the concentration of the species at a given timepoint. Red bubbles indicate that the concentration is decreasing and teal bubbles indicate that the concentration is increasing. Species that react with one another (including reverse reactions) are connected by blue ribbons. The width of the ribbon is scaled by the logarithm of the reaction rate coefficient (forward coefficient for the forward reaction and backward coefficient for the backward reaction, if applicable.)